stringtools
===========

.. automodule:: abjad.tools.stringtools

Functions
---------

.. toctree::
   :hidden:

   add_terminal_newlines
   capitalize_start
   delimit_words
   expr_to_bidirectional_direction_string
   expr_to_bidirectional_lilypond_symbol
   expr_to_tridirectional_direction_string
   expr_to_tridirectional_lilypond_symbol
   expr_to_tridirectional_ordinal_constant
   format_input_lines_as_doc_string
   is_dash_case
   is_dash_case_file_name
   is_lower_camel_case
   is_snake_case
   is_snake_case_file_name
   is_snake_case_file_name_with_extension
   is_snake_case_package_name
   is_space_delimited_lowercase
   is_string
   is_upper_camel_case
   normalize
   pluralize
   strip_diacritics
   to_accent_free_snake_case
   to_dash_case
   to_lower_camel_case
   to_snake_case
   to_space_delimited_lowercase
   to_upper_camel_case

.. autosummary::
   :nosignatures:

   add_terminal_newlines
   capitalize_start
   delimit_words
   expr_to_bidirectional_direction_string
   expr_to_bidirectional_lilypond_symbol
   expr_to_tridirectional_direction_string
   expr_to_tridirectional_lilypond_symbol
   expr_to_tridirectional_ordinal_constant
   format_input_lines_as_doc_string
   is_dash_case
   is_dash_case_file_name
   is_lower_camel_case
   is_snake_case
   is_snake_case_file_name
   is_snake_case_file_name_with_extension
   is_snake_case_package_name
   is_space_delimited_lowercase
   is_string
   is_upper_camel_case
   normalize
   pluralize
   strip_diacritics
   to_accent_free_snake_case
   to_dash_case
   to_lower_camel_case
   to_snake_case
   to_space_delimited_lowercase
   to_upper_camel_case
